@@ -65,6 +65,7 @@ __all__ = (
     "ReservationUtilizationGroupTypeDef",
     "UtilizationByTimeTypeDef",
     "GetReservationUtilizationResponseTypeDef",
+    "RightsizingRecommendationConfigurationTypeDef",
     "RightsizingRecommendationMetadataTypeDef",
     "RightsizingRecommendationSummaryTypeDef",
     "EC2ResourceDetailsTypeDef",
@@ -112,10 +113,12 @@ DimensionValuesTypeDef = TypedDict(
             "AZ",
             "INSTANCE_TYPE",
             "LINKED_ACCOUNT",
+            "LINKED_ACCOUNT_NAME",
             "OPERATION",
             "PURCHASE_TYPE",
             "REGION",
             "SERVICE",
+            "SERVICE_CODE",
             "USAGE_TYPE",
             "USAGE_TYPE_GROUP",
             "RECORD_TYPE",
@@ -138,11 +141,38 @@ DimensionValuesTypeDef = TypedDict(
             "PAYMENT_OPTION",
         ],
         "Values": List[str],
+        "MatchOptions": List[
+            Literal[
+                "EQUALS",
+                "STARTS_WITH",
+                "ENDS_WITH",
+                "CONTAINS",
+                "CASE_SENSITIVE",
+                "CASE_INSENSITIVE",
+            ]
+        ],
     },
     total=False,
 )
 
-TagValuesTypeDef = TypedDict("TagValuesTypeDef", {"Key": str, "Values": List[str]}, total=False)
+TagValuesTypeDef = TypedDict(
+    "TagValuesTypeDef",
+    {
+        "Key": str,
+        "Values": List[str],
+        "MatchOptions": List[
+            Literal[
+                "EQUALS",
+                "STARTS_WITH",
+                "ENDS_WITH",
+                "CONTAINS",
+                "CASE_SENSITIVE",
+                "CASE_INSENSITIVE",
+            ]
+        ],
+    },
+    total=False,
+)
 
 ExpressionTypeDef = TypedDict(
     "ExpressionTypeDef",
@@ -573,6 +603,14 @@ class GetReservationUtilizationResponseTypeDef(
     pass
 
 
+RightsizingRecommendationConfigurationTypeDef = TypedDict(
+    "RightsizingRecommendationConfigurationTypeDef",
+    {
+        "RecommendationTarget": Literal["SAME_INSTANCE_FAMILY", "CROSS_INSTANCE_FAMILY"],
+        "BenefitsConsidered": bool,
+    },
+)
+
 RightsizingRecommendationMetadataTypeDef = TypedDict(
     "RightsizingRecommendationMetadataTypeDef",
     {
@@ -691,6 +729,7 @@ GetRightsizingRecommendationResponseTypeDef = TypedDict(
         "Summary": RightsizingRecommendationSummaryTypeDef,
         "RightsizingRecommendations": List[RightsizingRecommendationTypeDef],
         "NextPageToken": str,
+        "Configuration": RightsizingRecommendationConfigurationTypeDef,
     },
     total=False,
 )
@@ -954,7 +993,13 @@ GetUsageForecastResponseTypeDef = TypedDict(
 
 CostCategoryReferenceTypeDef = TypedDict(
     "CostCategoryReferenceTypeDef",
-    {"CostCategoryArn": str, "Name": str, "EffectiveStart": str, "EffectiveEnd": str},
+    {
+        "CostCategoryArn": str,
+        "Name": str,
+        "EffectiveStart": str,
+        "EffectiveEnd": str,
+        "NumberOfRules": int,
+    },
     total=False,
 )
 
